'''
Copyright (C) 2023 Nat Hawkins & Mike Chappelow

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License (version 3 of the License)
as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
'''

from .plinko_hadoop import plinko_hadoop
from .plinko_sql import plinko_sql
from .plinko_s3R import plinko_s3R
from .plinko_s3 import plinko_s3
from .plinko_redshift import plinko_redshift
from .plinko_postgres import plinko_postgres